# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerSpecificationsHardwareResult',
    'AwaitableGetServerSpecificationsHardwareResult',
    'get_server_specifications_hardware',
    'get_server_specifications_hardware_output',
]

@pulumi.output_type
class GetServerSpecificationsHardwareResult:
    """
    A collection of values returned by getServerSpecificationsHardware.
    """
    def __init__(__self__, boot_mode=None, cores_per_processor=None, default_hardware_raid_size=None, default_hardware_raid_type=None, description=None, disk_groups=None, expansion_cards=None, form_factor=None, id=None, memory_size=None, motherboard=None, number_of_processors=None, processor_architecture=None, processor_name=None, service_name=None, threads_per_processor=None, usb_keys=None):
        if boot_mode and not isinstance(boot_mode, str):
            raise TypeError("Expected argument 'boot_mode' to be a str")
        pulumi.set(__self__, "boot_mode", boot_mode)
        if cores_per_processor and not isinstance(cores_per_processor, float):
            raise TypeError("Expected argument 'cores_per_processor' to be a float")
        pulumi.set(__self__, "cores_per_processor", cores_per_processor)
        if default_hardware_raid_size and not isinstance(default_hardware_raid_size, dict):
            raise TypeError("Expected argument 'default_hardware_raid_size' to be a dict")
        pulumi.set(__self__, "default_hardware_raid_size", default_hardware_raid_size)
        if default_hardware_raid_type and not isinstance(default_hardware_raid_type, str):
            raise TypeError("Expected argument 'default_hardware_raid_type' to be a str")
        pulumi.set(__self__, "default_hardware_raid_type", default_hardware_raid_type)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if disk_groups and not isinstance(disk_groups, list):
            raise TypeError("Expected argument 'disk_groups' to be a list")
        pulumi.set(__self__, "disk_groups", disk_groups)
        if expansion_cards and not isinstance(expansion_cards, list):
            raise TypeError("Expected argument 'expansion_cards' to be a list")
        pulumi.set(__self__, "expansion_cards", expansion_cards)
        if form_factor and not isinstance(form_factor, str):
            raise TypeError("Expected argument 'form_factor' to be a str")
        pulumi.set(__self__, "form_factor", form_factor)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if memory_size and not isinstance(memory_size, dict):
            raise TypeError("Expected argument 'memory_size' to be a dict")
        pulumi.set(__self__, "memory_size", memory_size)
        if motherboard and not isinstance(motherboard, str):
            raise TypeError("Expected argument 'motherboard' to be a str")
        pulumi.set(__self__, "motherboard", motherboard)
        if number_of_processors and not isinstance(number_of_processors, float):
            raise TypeError("Expected argument 'number_of_processors' to be a float")
        pulumi.set(__self__, "number_of_processors", number_of_processors)
        if processor_architecture and not isinstance(processor_architecture, str):
            raise TypeError("Expected argument 'processor_architecture' to be a str")
        pulumi.set(__self__, "processor_architecture", processor_architecture)
        if processor_name and not isinstance(processor_name, str):
            raise TypeError("Expected argument 'processor_name' to be a str")
        pulumi.set(__self__, "processor_name", processor_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if threads_per_processor and not isinstance(threads_per_processor, float):
            raise TypeError("Expected argument 'threads_per_processor' to be a float")
        pulumi.set(__self__, "threads_per_processor", threads_per_processor)
        if usb_keys and not isinstance(usb_keys, list):
            raise TypeError("Expected argument 'usb_keys' to be a list")
        pulumi.set(__self__, "usb_keys", usb_keys)

    @property
    @pulumi.getter(name="bootMode")
    def boot_mode(self) -> builtins.str:
        """
        Server boot mode
        """
        return pulumi.get(self, "boot_mode")

    @property
    @pulumi.getter(name="coresPerProcessor")
    def cores_per_processor(self) -> builtins.float:
        """
        Number of cores per processor
        """
        return pulumi.get(self, "cores_per_processor")

    @property
    @pulumi.getter(name="defaultHardwareRaidSize")
    def default_hardware_raid_size(self) -> 'outputs.GetServerSpecificationsHardwareDefaultHardwareRaidSizeResult':
        """
        Default hardware raid size for this disk group
        """
        return pulumi.get(self, "default_hardware_raid_size")

    @property
    @pulumi.getter(name="defaultHardwareRaidType")
    def default_hardware_raid_type(self) -> builtins.str:
        """
        Default hardware raid type for this disk group
        """
        return pulumi.get(self, "default_hardware_raid_type")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Expansion card description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="diskGroups")
    def disk_groups(self) -> Sequence['outputs.GetServerSpecificationsHardwareDiskGroupResult']:
        """
        Details about the groups of disks in the server
        """
        return pulumi.get(self, "disk_groups")

    @property
    @pulumi.getter(name="expansionCards")
    def expansion_cards(self) -> Sequence['outputs.GetServerSpecificationsHardwareExpansionCardResult']:
        """
        Details about the server's expansion cards
        """
        return pulumi.get(self, "expansion_cards")

    @property
    @pulumi.getter(name="formFactor")
    def form_factor(self) -> builtins.str:
        """
        Server form factor
        """
        return pulumi.get(self, "form_factor")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="memorySize")
    def memory_size(self) -> 'outputs.GetServerSpecificationsHardwareMemorySizeResult':
        """
        RAM capacity
        """
        return pulumi.get(self, "memory_size")

    @property
    @pulumi.getter
    def motherboard(self) -> builtins.str:
        """
        Server motherboard
        """
        return pulumi.get(self, "motherboard")

    @property
    @pulumi.getter(name="numberOfProcessors")
    def number_of_processors(self) -> builtins.float:
        """
        Number of processors in this dedicated server
        """
        return pulumi.get(self, "number_of_processors")

    @property
    @pulumi.getter(name="processorArchitecture")
    def processor_architecture(self) -> builtins.str:
        """
        Processor architecture bit
        """
        return pulumi.get(self, "processor_architecture")

    @property
    @pulumi.getter(name="processorName")
    def processor_name(self) -> builtins.str:
        """
        Processor name
        """
        return pulumi.get(self, "processor_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="threadsPerProcessor")
    def threads_per_processor(self) -> builtins.float:
        """
        Number of threads per processor
        """
        return pulumi.get(self, "threads_per_processor")

    @property
    @pulumi.getter(name="usbKeys")
    def usb_keys(self) -> Sequence['outputs.GetServerSpecificationsHardwareUsbKeyResult']:
        """
        Capacity of the USB keys installed on your server, if any
        """
        return pulumi.get(self, "usb_keys")


class AwaitableGetServerSpecificationsHardwareResult(GetServerSpecificationsHardwareResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerSpecificationsHardwareResult(
            boot_mode=self.boot_mode,
            cores_per_processor=self.cores_per_processor,
            default_hardware_raid_size=self.default_hardware_raid_size,
            default_hardware_raid_type=self.default_hardware_raid_type,
            description=self.description,
            disk_groups=self.disk_groups,
            expansion_cards=self.expansion_cards,
            form_factor=self.form_factor,
            id=self.id,
            memory_size=self.memory_size,
            motherboard=self.motherboard,
            number_of_processors=self.number_of_processors,
            processor_architecture=self.processor_architecture,
            processor_name=self.processor_name,
            service_name=self.service_name,
            threads_per_processor=self.threads_per_processor,
            usb_keys=self.usb_keys)


def get_server_specifications_hardware(service_name: Optional[builtins.str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerSpecificationsHardwareResult:
    """
    Use this data source to get the hardward information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    spec = ovh.Dedicated.get_server_specifications_hardware(service_name="myserver")
    ```


    :param builtins.str service_name: The internal name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dedicated/getServerSpecificationsHardware:getServerSpecificationsHardware', __args__, opts=opts, typ=GetServerSpecificationsHardwareResult).value

    return AwaitableGetServerSpecificationsHardwareResult(
        boot_mode=pulumi.get(__ret__, 'boot_mode'),
        cores_per_processor=pulumi.get(__ret__, 'cores_per_processor'),
        default_hardware_raid_size=pulumi.get(__ret__, 'default_hardware_raid_size'),
        default_hardware_raid_type=pulumi.get(__ret__, 'default_hardware_raid_type'),
        description=pulumi.get(__ret__, 'description'),
        disk_groups=pulumi.get(__ret__, 'disk_groups'),
        expansion_cards=pulumi.get(__ret__, 'expansion_cards'),
        form_factor=pulumi.get(__ret__, 'form_factor'),
        id=pulumi.get(__ret__, 'id'),
        memory_size=pulumi.get(__ret__, 'memory_size'),
        motherboard=pulumi.get(__ret__, 'motherboard'),
        number_of_processors=pulumi.get(__ret__, 'number_of_processors'),
        processor_architecture=pulumi.get(__ret__, 'processor_architecture'),
        processor_name=pulumi.get(__ret__, 'processor_name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        threads_per_processor=pulumi.get(__ret__, 'threads_per_processor'),
        usb_keys=pulumi.get(__ret__, 'usb_keys'))
def get_server_specifications_hardware_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerSpecificationsHardwareResult]:
    """
    Use this data source to get the hardward information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    spec = ovh.Dedicated.get_server_specifications_hardware(service_name="myserver")
    ```


    :param builtins.str service_name: The internal name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dedicated/getServerSpecificationsHardware:getServerSpecificationsHardware', __args__, opts=opts, typ=GetServerSpecificationsHardwareResult)
    return __ret__.apply(lambda __response__: GetServerSpecificationsHardwareResult(
        boot_mode=pulumi.get(__response__, 'boot_mode'),
        cores_per_processor=pulumi.get(__response__, 'cores_per_processor'),
        default_hardware_raid_size=pulumi.get(__response__, 'default_hardware_raid_size'),
        default_hardware_raid_type=pulumi.get(__response__, 'default_hardware_raid_type'),
        description=pulumi.get(__response__, 'description'),
        disk_groups=pulumi.get(__response__, 'disk_groups'),
        expansion_cards=pulumi.get(__response__, 'expansion_cards'),
        form_factor=pulumi.get(__response__, 'form_factor'),
        id=pulumi.get(__response__, 'id'),
        memory_size=pulumi.get(__response__, 'memory_size'),
        motherboard=pulumi.get(__response__, 'motherboard'),
        number_of_processors=pulumi.get(__response__, 'number_of_processors'),
        processor_architecture=pulumi.get(__response__, 'processor_architecture'),
        processor_name=pulumi.get(__response__, 'processor_name'),
        service_name=pulumi.get(__response__, 'service_name'),
        threads_per_processor=pulumi.get(__response__, 'threads_per_processor'),
        usb_keys=pulumi.get(__response__, 'usb_keys')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RancherArgs', 'Rancher']

@pulumi.input_type
class RancherArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[builtins.str],
                 target_spec: pulumi.Input['RancherTargetSpecArgs']):
        """
        The set of arguments for constructing a Rancher resource.
        :param pulumi.Input[builtins.str] project_id: Project ID
        :param pulumi.Input['RancherTargetSpecArgs'] target_spec: Target specification for the managed Rancher service
        """
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "target_spec", target_spec)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[builtins.str]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="targetSpec")
    def target_spec(self) -> pulumi.Input['RancherTargetSpecArgs']:
        """
        Target specification for the managed Rancher service
        """
        return pulumi.get(self, "target_spec")

    @target_spec.setter
    def target_spec(self, value: pulumi.Input['RancherTargetSpecArgs']):
        pulumi.set(self, "target_spec", value)


@pulumi.input_type
class _RancherState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 current_state: Optional[pulumi.Input['RancherCurrentStateArgs']] = None,
                 current_tasks: Optional[pulumi.Input[Sequence[pulumi.Input['RancherCurrentTaskArgs']]]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 resource_status: Optional[pulumi.Input[builtins.str]] = None,
                 target_spec: Optional[pulumi.Input['RancherTargetSpecArgs']] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Rancher resources.
        :param pulumi.Input[builtins.str] created_at: Date of the managed Rancher service creation
        :param pulumi.Input['RancherCurrentStateArgs'] current_state: Current configuration applied to the managed Rancher service
        :param pulumi.Input[Sequence[pulumi.Input['RancherCurrentTaskArgs']]] current_tasks: Asynchronous operations ongoing on the managed Rancher service
        :param pulumi.Input[builtins.str] project_id: Project ID
        :param pulumi.Input[builtins.str] resource_status: Reflects the readiness of the managed Rancher service. A new target specification request will be accepted only in `READY` status
        :param pulumi.Input['RancherTargetSpecArgs'] target_spec: Target specification for the managed Rancher service
        :param pulumi.Input[builtins.str] updated_at: Date of the last managed Rancher service update
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_state is not None:
            pulumi.set(__self__, "current_state", current_state)
        if current_tasks is not None:
            pulumi.set(__self__, "current_tasks", current_tasks)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if resource_status is not None:
            pulumi.set(__self__, "resource_status", resource_status)
        if target_spec is not None:
            pulumi.set(__self__, "target_spec", target_spec)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the managed Rancher service creation
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="currentState")
    def current_state(self) -> Optional[pulumi.Input['RancherCurrentStateArgs']]:
        """
        Current configuration applied to the managed Rancher service
        """
        return pulumi.get(self, "current_state")

    @current_state.setter
    def current_state(self, value: Optional[pulumi.Input['RancherCurrentStateArgs']]):
        pulumi.set(self, "current_state", value)

    @property
    @pulumi.getter(name="currentTasks")
    def current_tasks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RancherCurrentTaskArgs']]]]:
        """
        Asynchronous operations ongoing on the managed Rancher service
        """
        return pulumi.get(self, "current_tasks")

    @current_tasks.setter
    def current_tasks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RancherCurrentTaskArgs']]]]):
        pulumi.set(self, "current_tasks", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="resourceStatus")
    def resource_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Reflects the readiness of the managed Rancher service. A new target specification request will be accepted only in `READY` status
        """
        return pulumi.get(self, "resource_status")

    @resource_status.setter
    def resource_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_status", value)

    @property
    @pulumi.getter(name="targetSpec")
    def target_spec(self) -> Optional[pulumi.Input['RancherTargetSpecArgs']]:
        """
        Target specification for the managed Rancher service
        """
        return pulumi.get(self, "target_spec")

    @target_spec.setter
    def target_spec(self, value: Optional[pulumi.Input['RancherTargetSpecArgs']]):
        pulumi.set(self, "target_spec", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last managed Rancher service update
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("ovh:CloudProject/rancher:Rancher")
class Rancher(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 target_spec: Optional[pulumi.Input[Union['RancherTargetSpecArgs', 'RancherTargetSpecArgsDict']]] = None,
                 __props__=None):
        """
        Manage a Rancher service in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        rancher = ovh.cloud_project.Rancher("rancher",
            project_id="<public cloud project ID>",
            target_spec={
                "name": "MyRancher",
                "plan": "STANDARD",
            })
        pulumi.export("rancherUrl", rancher.current_state.url)
        ```

        ## Import

        A share in a public cloud project can be imported using the `project_id` and `id` attributes. Using the following configuration:

        terraform

        import {

          id = "<project_id>/<id>"

          to = ovh_cloud_project_rancher.rancher

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=rancher.tf

        $ pulumi up

        The file `rancher.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] project_id: Project ID
        :param pulumi.Input[Union['RancherTargetSpecArgs', 'RancherTargetSpecArgsDict']] target_spec: Target specification for the managed Rancher service
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RancherArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage a Rancher service in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        rancher = ovh.cloud_project.Rancher("rancher",
            project_id="<public cloud project ID>",
            target_spec={
                "name": "MyRancher",
                "plan": "STANDARD",
            })
        pulumi.export("rancherUrl", rancher.current_state.url)
        ```

        ## Import

        A share in a public cloud project can be imported using the `project_id` and `id` attributes. Using the following configuration:

        terraform

        import {

          id = "<project_id>/<id>"

          to = ovh_cloud_project_rancher.rancher

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=rancher.tf

        $ pulumi up

        The file `rancher.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param RancherArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RancherArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 target_spec: Optional[pulumi.Input[Union['RancherTargetSpecArgs', 'RancherTargetSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RancherArgs.__new__(RancherArgs)

            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if target_spec is None and not opts.urn:
                raise TypeError("Missing required property 'target_spec'")
            __props__.__dict__["target_spec"] = target_spec
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_state"] = None
            __props__.__dict__["current_tasks"] = None
            __props__.__dict__["resource_status"] = None
            __props__.__dict__["updated_at"] = None
        super(Rancher, __self__).__init__(
            'ovh:CloudProject/rancher:Rancher',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            current_state: Optional[pulumi.Input[Union['RancherCurrentStateArgs', 'RancherCurrentStateArgsDict']]] = None,
            current_tasks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RancherCurrentTaskArgs', 'RancherCurrentTaskArgsDict']]]]] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            resource_status: Optional[pulumi.Input[builtins.str]] = None,
            target_spec: Optional[pulumi.Input[Union['RancherTargetSpecArgs', 'RancherTargetSpecArgsDict']]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'Rancher':
        """
        Get an existing Rancher resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_at: Date of the managed Rancher service creation
        :param pulumi.Input[Union['RancherCurrentStateArgs', 'RancherCurrentStateArgsDict']] current_state: Current configuration applied to the managed Rancher service
        :param pulumi.Input[Sequence[pulumi.Input[Union['RancherCurrentTaskArgs', 'RancherCurrentTaskArgsDict']]]] current_tasks: Asynchronous operations ongoing on the managed Rancher service
        :param pulumi.Input[builtins.str] project_id: Project ID
        :param pulumi.Input[builtins.str] resource_status: Reflects the readiness of the managed Rancher service. A new target specification request will be accepted only in `READY` status
        :param pulumi.Input[Union['RancherTargetSpecArgs', 'RancherTargetSpecArgsDict']] target_spec: Target specification for the managed Rancher service
        :param pulumi.Input[builtins.str] updated_at: Date of the last managed Rancher service update
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RancherState.__new__(_RancherState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_state"] = current_state
        __props__.__dict__["current_tasks"] = current_tasks
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["resource_status"] = resource_status
        __props__.__dict__["target_spec"] = target_spec
        __props__.__dict__["updated_at"] = updated_at
        return Rancher(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the managed Rancher service creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentState")
    def current_state(self) -> pulumi.Output['outputs.RancherCurrentState']:
        """
        Current configuration applied to the managed Rancher service
        """
        return pulumi.get(self, "current_state")

    @property
    @pulumi.getter(name="currentTasks")
    def current_tasks(self) -> pulumi.Output[Sequence['outputs.RancherCurrentTask']]:
        """
        Asynchronous operations ongoing on the managed Rancher service
        """
        return pulumi.get(self, "current_tasks")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="resourceStatus")
    def resource_status(self) -> pulumi.Output[builtins.str]:
        """
        Reflects the readiness of the managed Rancher service. A new target specification request will be accepted only in `READY` status
        """
        return pulumi.get(self, "resource_status")

    @property
    @pulumi.getter(name="targetSpec")
    def target_spec(self) -> pulumi.Output['outputs.RancherTargetSpec']:
        """
        Target specification for the managed Rancher service
        """
        return pulumi.get(self, "target_spec")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the last managed Rancher service update
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCloudProjectSshKeysResult',
    'AwaitableGetCloudProjectSshKeysResult',
    'get_cloud_project_ssh_keys',
    'get_cloud_project_ssh_keys_output',
]

@pulumi.output_type
class GetCloudProjectSshKeysResult:
    """
    A collection of values returned by getCloudProjectSshKeys.
    """
    def __init__(__self__, id=None, region=None, service_name=None, ssh_keys=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if ssh_keys and not isinstance(ssh_keys, list):
            raise TypeError("Expected argument 'ssh_keys' to be a list")
        pulumi.set(__self__, "ssh_keys", ssh_keys)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sshKeys")
    def ssh_keys(self) -> Sequence['outputs.GetCloudProjectSshKeysSshKeyResult']:
        return pulumi.get(self, "ssh_keys")


class AwaitableGetCloudProjectSshKeysResult(GetCloudProjectSshKeysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudProjectSshKeysResult(
            id=self.id,
            region=self.region,
            service_name=self.service_name,
            ssh_keys=self.ssh_keys)


def get_cloud_project_ssh_keys(region: Optional[builtins.str] = None,
                               service_name: Optional[builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudProjectSshKeysResult:
    """
    Get SSH keys in a Public Cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    keys = ovh.get_cloud_project_ssh_keys(service_name="XXX")
    ```


    :param builtins.str region: Region
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getCloudProjectSshKeys:getCloudProjectSshKeys', __args__, opts=opts, typ=GetCloudProjectSshKeysResult).value

    return AwaitableGetCloudProjectSshKeysResult(
        id=pulumi.get(__ret__, 'id'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        ssh_keys=pulumi.get(__ret__, 'ssh_keys'))
def get_cloud_project_ssh_keys_output(region: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                      service_name: Optional[pulumi.Input[builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudProjectSshKeysResult]:
    """
    Get SSH keys in a Public Cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    keys = ovh.get_cloud_project_ssh_keys(service_name="XXX")
    ```


    :param builtins.str region: Region
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getCloudProjectSshKeys:getCloudProjectSshKeys', __args__, opts=opts, typ=GetCloudProjectSshKeysResult)
    return __ret__.apply(lambda __response__: GetCloudProjectSshKeysResult(
        id=pulumi.get(__response__, 'id'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        ssh_keys=pulumi.get(__response__, 'ssh_keys')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFloatingIPsResult',
    'AwaitableGetFloatingIPsResult',
    'get_floating_ips',
    'get_floating_ips_output',
]

@pulumi.output_type
class GetFloatingIPsResult:
    """
    A collection of values returned by getFloatingIPs.
    """
    def __init__(__self__, cloud_project_floatingips=None, id=None, region_name=None, service_name=None):
        if cloud_project_floatingips and not isinstance(cloud_project_floatingips, list):
            raise TypeError("Expected argument 'cloud_project_floatingips' to be a list")
        pulumi.set(__self__, "cloud_project_floatingips", cloud_project_floatingips)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if region_name and not isinstance(region_name, str):
            raise TypeError("Expected argument 'region_name' to be a str")
        pulumi.set(__self__, "region_name", region_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="cloudProjectFloatingips")
    def cloud_project_floatingips(self) -> Sequence['outputs.GetFloatingIPsCloudProjectFloatingipResult']:
        return pulumi.get(self, "cloud_project_floatingips")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> builtins.str:
        """
        Floating IP region
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")


class AwaitableGetFloatingIPsResult(GetFloatingIPsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFloatingIPsResult(
            cloud_project_floatingips=self.cloud_project_floatingips,
            id=self.id,
            region_name=self.region_name,
            service_name=self.service_name)


def get_floating_ips(region_name: Optional[builtins.str] = None,
                     service_name: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFloatingIPsResult:
    """
    Use this data source to get the floating IPs of a public cloud project.


    :param builtins.str region_name: Public cloud region name
    :param builtins.str service_name: The id of the public cloud project
    """
    __args__ = dict()
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getFloatingIPs:getFloatingIPs', __args__, opts=opts, typ=GetFloatingIPsResult).value

    return AwaitableGetFloatingIPsResult(
        cloud_project_floatingips=pulumi.get(__ret__, 'cloud_project_floatingips'),
        id=pulumi.get(__ret__, 'id'),
        region_name=pulumi.get(__ret__, 'region_name'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_floating_ips_output(region_name: Optional[pulumi.Input[builtins.str]] = None,
                            service_name: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFloatingIPsResult]:
    """
    Use this data source to get the floating IPs of a public cloud project.


    :param builtins.str region_name: Public cloud region name
    :param builtins.str service_name: The id of the public cloud project
    """
    __args__ = dict()
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getFloatingIPs:getFloatingIPs', __args__, opts=opts, typ=GetFloatingIPsResult)
    return __ret__.apply(lambda __response__: GetFloatingIPsResult(
        cloud_project_floatingips=pulumi.get(__response__, 'cloud_project_floatingips'),
        id=pulumi.get(__response__, 'id'),
        region_name=pulumi.get(__response__, 'region_name'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetVpsResult',
    'AwaitableGetVpsResult',
    'get_vps',
    'get_vps_output',
]

@pulumi.output_type
class GetVpsResult:
    """
    A collection of values returned by getVps.
    """
    def __init__(__self__, vps_urn=None, cluster=None, datacenter=None, displayname=None, id=None, ips=None, keymap=None, memory=None, model=None, name=None, netbootmode=None, offertype=None, service_name=None, slamonitoring=None, state=None, type=None, vcore=None, zone=None):
        if vps_urn and not isinstance(vps_urn, str):
            raise TypeError("Expected argument 'vps_urn' to be a str")
        pulumi.set(__self__, "vps_urn", vps_urn)
        if cluster and not isinstance(cluster, str):
            raise TypeError("Expected argument 'cluster' to be a str")
        pulumi.set(__self__, "cluster", cluster)
        if datacenter and not isinstance(datacenter, dict):
            raise TypeError("Expected argument 'datacenter' to be a dict")
        pulumi.set(__self__, "datacenter", datacenter)
        if displayname and not isinstance(displayname, str):
            raise TypeError("Expected argument 'displayname' to be a str")
        pulumi.set(__self__, "displayname", displayname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if keymap and not isinstance(keymap, str):
            raise TypeError("Expected argument 'keymap' to be a str")
        pulumi.set(__self__, "keymap", keymap)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if model and not isinstance(model, dict):
            raise TypeError("Expected argument 'model' to be a dict")
        pulumi.set(__self__, "model", model)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if netbootmode and not isinstance(netbootmode, str):
            raise TypeError("Expected argument 'netbootmode' to be a str")
        pulumi.set(__self__, "netbootmode", netbootmode)
        if offertype and not isinstance(offertype, str):
            raise TypeError("Expected argument 'offertype' to be a str")
        pulumi.set(__self__, "offertype", offertype)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if slamonitoring and not isinstance(slamonitoring, bool):
            raise TypeError("Expected argument 'slamonitoring' to be a bool")
        pulumi.set(__self__, "slamonitoring", slamonitoring)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if vcore and not isinstance(vcore, int):
            raise TypeError("Expected argument 'vcore' to be a int")
        pulumi.set(__self__, "vcore", vcore)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="VpsURN")
    def vps_urn(self) -> builtins.str:
        """
        The URN of the vps
        """
        return pulumi.get(self, "vps_urn")

    @property
    @pulumi.getter
    def cluster(self) -> builtins.str:
        """
        The OVHcloud cluster the vps is in
        """
        return pulumi.get(self, "cluster")

    @property
    @pulumi.getter
    def datacenter(self) -> Mapping[str, builtins.str]:
        """
        The datacenter in which the vps is located
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter
    def displayname(self) -> builtins.str:
        """
        The displayed name in the OVHcloud web admin
        """
        return pulumi.get(self, "displayname")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ips(self) -> Sequence[builtins.str]:
        """
        The list of IPs addresses attached to the vps
        """
        return pulumi.get(self, "ips")

    @property
    @pulumi.getter
    def keymap(self) -> builtins.str:
        """
        The keymap for the ip kvm, valid values "", "fr", "us"
        """
        return pulumi.get(self, "keymap")

    @property
    @pulumi.getter
    def memory(self) -> builtins.int:
        """
        The amount of memory in MB of the vps.
        """
        return pulumi.get(self, "memory")

    @property
    @pulumi.getter
    def model(self) -> Mapping[str, builtins.str]:
        """
        A dict describing the type of vps.
        """
        return pulumi.get(self, "model")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def netbootmode(self) -> builtins.str:
        """
        The source of the boot kernel
        """
        return pulumi.get(self, "netbootmode")

    @property
    @pulumi.getter
    def offertype(self) -> builtins.str:
        """
        The type of offer (ssd, cloud, classic)
        """
        return pulumi.get(self, "offertype")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def slamonitoring(self) -> builtins.bool:
        """
        A boolean to indicate if OVHcloud SLA monitoring is active.
        """
        return pulumi.get(self, "slamonitoring")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        The state of the vps
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        The type of server
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def vcore(self) -> builtins.int:
        """
        The number of vcore of the vps
        """
        return pulumi.get(self, "vcore")

    @property
    @pulumi.getter
    def zone(self) -> builtins.str:
        """
        The OVHcloud zone where the vps is
        """
        return pulumi.get(self, "zone")


class AwaitableGetVpsResult(GetVpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpsResult(
            vps_urn=self.vps_urn,
            cluster=self.cluster,
            datacenter=self.datacenter,
            displayname=self.displayname,
            id=self.id,
            ips=self.ips,
            keymap=self.keymap,
            memory=self.memory,
            model=self.model,
            name=self.name,
            netbootmode=self.netbootmode,
            offertype=self.offertype,
            service_name=self.service_name,
            slamonitoring=self.slamonitoring,
            state=self.state,
            type=self.type,
            vcore=self.vcore,
            zone=self.zone)


def get_vps(service_name: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpsResult:
    """
    Use this data source to retrieve information about a vps associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    server = ovh.Vps.get_vps(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service_name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Vps/getVps:getVps', __args__, opts=opts, typ=GetVpsResult).value

    return AwaitableGetVpsResult(
        vps_urn=pulumi.get(__ret__, 'vps_urn'),
        cluster=pulumi.get(__ret__, 'cluster'),
        datacenter=pulumi.get(__ret__, 'datacenter'),
        displayname=pulumi.get(__ret__, 'displayname'),
        id=pulumi.get(__ret__, 'id'),
        ips=pulumi.get(__ret__, 'ips'),
        keymap=pulumi.get(__ret__, 'keymap'),
        memory=pulumi.get(__ret__, 'memory'),
        model=pulumi.get(__ret__, 'model'),
        name=pulumi.get(__ret__, 'name'),
        netbootmode=pulumi.get(__ret__, 'netbootmode'),
        offertype=pulumi.get(__ret__, 'offertype'),
        service_name=pulumi.get(__ret__, 'service_name'),
        slamonitoring=pulumi.get(__ret__, 'slamonitoring'),
        state=pulumi.get(__ret__, 'state'),
        type=pulumi.get(__ret__, 'type'),
        vcore=pulumi.get(__ret__, 'vcore'),
        zone=pulumi.get(__ret__, 'zone'))
def get_vps_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpsResult]:
    """
    Use this data source to retrieve information about a vps associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    server = ovh.Vps.get_vps(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The service_name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Vps/getVps:getVps', __args__, opts=opts, typ=GetVpsResult)
    return __ret__.apply(lambda __response__: GetVpsResult(
        vps_urn=pulumi.get(__response__, 'vps_urn'),
        cluster=pulumi.get(__response__, 'cluster'),
        datacenter=pulumi.get(__response__, 'datacenter'),
        displayname=pulumi.get(__response__, 'displayname'),
        id=pulumi.get(__response__, 'id'),
        ips=pulumi.get(__response__, 'ips'),
        keymap=pulumi.get(__response__, 'keymap'),
        memory=pulumi.get(__response__, 'memory'),
        model=pulumi.get(__response__, 'model'),
        name=pulumi.get(__response__, 'name'),
        netbootmode=pulumi.get(__response__, 'netbootmode'),
        offertype=pulumi.get(__response__, 'offertype'),
        service_name=pulumi.get(__response__, 'service_name'),
        slamonitoring=pulumi.get(__response__, 'slamonitoring'),
        state=pulumi.get(__response__, 'state'),
        type=pulumi.get(__response__, 'type'),
        vcore=pulumi.get(__response__, 'vcore'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HttpFarmArgs', 'HttpFarm']

@pulumi.input_type
class HttpFarmArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[builtins.str],
                 zone: pulumi.Input[builtins.str],
                 balance: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input['HttpFarmProbeArgs']] = None,
                 stickiness: Optional[pulumi.Input[builtins.str]] = None,
                 vrack_network_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        The set of arguments for constructing a HttpFarm resource.
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] zone: Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        :param pulumi.Input[builtins.str] balance: Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        :param pulumi.Input[builtins.str] display_name: Readable label for loadbalancer farm
        :param pulumi.Input[builtins.int] port: Port attached to your farm ([1..49151]). Inherited from frontend if null
        :param pulumi.Input['HttpFarmProbeArgs'] probe: define a backend healthcheck probe
        :param pulumi.Input[builtins.str] stickiness: Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        :param pulumi.Input[builtins.int] vrack_network_id: Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        """
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "zone", zone)
        if balance is not None:
            pulumi.set(__self__, "balance", balance)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if probe is not None:
            pulumi.set(__self__, "probe", probe)
        if stickiness is not None:
            pulumi.set(__self__, "stickiness", stickiness)
        if vrack_network_id is not None:
            pulumi.set(__self__, "vrack_network_id", vrack_network_id)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Input[builtins.str]:
        """
        Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone", value)

    @property
    @pulumi.getter
    def balance(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        """
        return pulumi.get(self, "balance")

    @balance.setter
    def balance(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "balance", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Readable label for loadbalancer farm
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port attached to your farm ([1..49151]). Inherited from frontend if null
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def probe(self) -> Optional[pulumi.Input['HttpFarmProbeArgs']]:
        """
        define a backend healthcheck probe
        """
        return pulumi.get(self, "probe")

    @probe.setter
    def probe(self, value: Optional[pulumi.Input['HttpFarmProbeArgs']]):
        pulumi.set(self, "probe", value)

    @property
    @pulumi.getter
    def stickiness(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        """
        return pulumi.get(self, "stickiness")

    @stickiness.setter
    def stickiness(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stickiness", value)

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        """
        return pulumi.get(self, "vrack_network_id")

    @vrack_network_id.setter
    def vrack_network_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vrack_network_id", value)


@pulumi.input_type
class _HttpFarmState:
    def __init__(__self__, *,
                 balance: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input['HttpFarmProbeArgs']] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[builtins.str]] = None,
                 vrack_network_id: Optional[pulumi.Input[builtins.int]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering HttpFarm resources.
        :param pulumi.Input[builtins.str] balance: Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        :param pulumi.Input[builtins.str] display_name: Readable label for loadbalancer farm
        :param pulumi.Input[builtins.int] port: Port attached to your farm ([1..49151]). Inherited from frontend if null
        :param pulumi.Input['HttpFarmProbeArgs'] probe: define a backend healthcheck probe
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] stickiness: Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        :param pulumi.Input[builtins.int] vrack_network_id: Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        :param pulumi.Input[builtins.str] zone: Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        if balance is not None:
            pulumi.set(__self__, "balance", balance)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if probe is not None:
            pulumi.set(__self__, "probe", probe)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if stickiness is not None:
            pulumi.set(__self__, "stickiness", stickiness)
        if vrack_network_id is not None:
            pulumi.set(__self__, "vrack_network_id", vrack_network_id)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter
    def balance(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        """
        return pulumi.get(self, "balance")

    @balance.setter
    def balance(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "balance", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Readable label for loadbalancer farm
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Port attached to your farm ([1..49151]). Inherited from frontend if null
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def probe(self) -> Optional[pulumi.Input['HttpFarmProbeArgs']]:
        """
        define a backend healthcheck probe
        """
        return pulumi.get(self, "probe")

    @probe.setter
    def probe(self, value: Optional[pulumi.Input['HttpFarmProbeArgs']]):
        pulumi.set(self, "probe", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def stickiness(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        """
        return pulumi.get(self, "stickiness")

    @stickiness.setter
    def stickiness(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stickiness", value)

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        """
        return pulumi.get(self, "vrack_network_id")

    @vrack_network_id.setter
    def vrack_network_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "vrack_network_id", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("ovh:IpLoadBalancing/httpFarm:HttpFarm")
class HttpFarm(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 balance: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[Union['HttpFarmProbeArgs', 'HttpFarmProbeArgsDict']]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[builtins.str]] = None,
                 vrack_network_id: Optional[pulumi.Input[builtins.int]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a HTTP backend server group (farm) to be used by loadbalancing frontend(s)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farmname = ovh.ip_load_balancing.HttpFarm("farmname",
            service_name=lb.service_name,
            display_name="ingress-8080-gra",
            zone="GRA")
        ```

        ## Import

        HTTP farm can be imported using the following format `service_name` and the `id` of the farm, separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpFarm:HttpFarm farmname service_name/farm_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] balance: Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        :param pulumi.Input[builtins.str] display_name: Readable label for loadbalancer farm
        :param pulumi.Input[builtins.int] port: Port attached to your farm ([1..49151]). Inherited from frontend if null
        :param pulumi.Input[Union['HttpFarmProbeArgs', 'HttpFarmProbeArgsDict']] probe: define a backend healthcheck probe
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] stickiness: Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        :param pulumi.Input[builtins.int] vrack_network_id: Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        :param pulumi.Input[builtins.str] zone: Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpFarmArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a HTTP backend server group (farm) to be used by loadbalancing frontend(s)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farmname = ovh.ip_load_balancing.HttpFarm("farmname",
            service_name=lb.service_name,
            display_name="ingress-8080-gra",
            zone="GRA")
        ```

        ## Import

        HTTP farm can be imported using the following format `service_name` and the `id` of the farm, separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/httpFarm:HttpFarm farmname service_name/farm_id
        ```

        :param str resource_name: The name of the resource.
        :param HttpFarmArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpFarmArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 balance: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 probe: Optional[pulumi.Input[Union['HttpFarmProbeArgs', 'HttpFarmProbeArgsDict']]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stickiness: Optional[pulumi.Input[builtins.str]] = None,
                 vrack_network_id: Optional[pulumi.Input[builtins.int]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpFarmArgs.__new__(HttpFarmArgs)

            __props__.__dict__["balance"] = balance
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["port"] = port
            __props__.__dict__["probe"] = probe
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["stickiness"] = stickiness
            __props__.__dict__["vrack_network_id"] = vrack_network_id
            if zone is None and not opts.urn:
                raise TypeError("Missing required property 'zone'")
            __props__.__dict__["zone"] = zone
        super(HttpFarm, __self__).__init__(
            'ovh:IpLoadBalancing/httpFarm:HttpFarm',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            balance: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            probe: Optional[pulumi.Input[Union['HttpFarmProbeArgs', 'HttpFarmProbeArgsDict']]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            stickiness: Optional[pulumi.Input[builtins.str]] = None,
            vrack_network_id: Optional[pulumi.Input[builtins.int]] = None,
            zone: Optional[pulumi.Input[builtins.str]] = None) -> 'HttpFarm':
        """
        Get an existing HttpFarm resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] balance: Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        :param pulumi.Input[builtins.str] display_name: Readable label for loadbalancer farm
        :param pulumi.Input[builtins.int] port: Port attached to your farm ([1..49151]). Inherited from frontend if null
        :param pulumi.Input[Union['HttpFarmProbeArgs', 'HttpFarmProbeArgsDict']] probe: define a backend healthcheck probe
        :param pulumi.Input[builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[builtins.str] stickiness: Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        :param pulumi.Input[builtins.int] vrack_network_id: Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        :param pulumi.Input[builtins.str] zone: Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpFarmState.__new__(_HttpFarmState)

        __props__.__dict__["balance"] = balance
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["port"] = port
        __props__.__dict__["probe"] = probe
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["stickiness"] = stickiness
        __props__.__dict__["vrack_network_id"] = vrack_network_id
        __props__.__dict__["zone"] = zone
        return HttpFarm(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def balance(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Load balancing algorithm. `roundrobin` if null (`first`, `leastconn`, `roundrobin`, `source`, `uri`)
        """
        return pulumi.get(self, "balance")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Readable label for loadbalancer farm
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Port attached to your farm ([1..49151]). Inherited from frontend if null
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter
    def probe(self) -> pulumi.Output[Optional['outputs.HttpFarmProbe']]:
        """
        define a backend healthcheck probe
        """
        return pulumi.get(self, "probe")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def stickiness(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Stickiness type. No stickiness if null (`sourceIp`, `cookie`)
        """
        return pulumi.get(self, "stickiness")

    @property
    @pulumi.getter(name="vrackNetworkId")
    def vrack_network_id(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Internal Load Balancer identifier of the vRack private network to attach to your farm, mandatory when your Load Balancer is attached to a vRack
        """
        return pulumi.get(self, "vrack_network_id")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[builtins.str]:
        """
        Zone where the farm will be defined (ie. `GRA`, `BHS` also supports `ALL`)
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRancherVersionResult',
    'AwaitableGetRancherVersionResult',
    'get_rancher_version',
    'get_rancher_version_output',
]

@pulumi.output_type
class GetRancherVersionResult:
    """
    A collection of values returned by getRancherVersion.
    """
    def __init__(__self__, id=None, project_id=None, versions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if versions and not isinstance(versions, list):
            raise TypeError("Expected argument 'versions' to be a list")
        pulumi.set(__self__, "versions", versions)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def versions(self) -> Sequence['outputs.GetRancherVersionVersionResult']:
        return pulumi.get(self, "versions")


class AwaitableGetRancherVersionResult(GetRancherVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRancherVersionResult(
            id=self.id,
            project_id=self.project_id,
            versions=self.versions)


def get_rancher_version(project_id: Optional[builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRancherVersionResult:
    """
    Use this datasource to retrieve information about the Managed Rancher available versions in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    versions = ovh.CloudProject.get_rancher_version(project_id="XXXXXX")
    ```


    :param builtins.str project_id: Project ID
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getRancherVersion:getRancherVersion', __args__, opts=opts, typ=GetRancherVersionResult).value

    return AwaitableGetRancherVersionResult(
        id=pulumi.get(__ret__, 'id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        versions=pulumi.get(__ret__, 'versions'))
def get_rancher_version_output(project_id: Optional[pulumi.Input[builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRancherVersionResult]:
    """
    Use this datasource to retrieve information about the Managed Rancher available versions in the given public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    versions = ovh.CloudProject.get_rancher_version(project_id="XXXXXX")
    ```


    :param builtins.str project_id: Project ID
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getRancherVersion:getRancherVersion', __args__, opts=opts, typ=GetRancherVersionResult)
    return __ret__.apply(lambda __response__: GetRancherVersionResult(
        id=pulumi.get(__response__, 'id'),
        project_id=pulumi.get(__response__, 'project_id'),
        versions=pulumi.get(__response__, 'versions')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCartProductOptionsResult',
    'AwaitableGetCartProductOptionsResult',
    'get_cart_product_options',
    'get_cart_product_options_output',
]

@pulumi.output_type
class GetCartProductOptionsResult:
    """
    A collection of values returned by getCartProductOptions.
    """
    def __init__(__self__, cart_id=None, catalog_name=None, id=None, plan_code=None, product=None, results=None):
        if cart_id and not isinstance(cart_id, str):
            raise TypeError("Expected argument 'cart_id' to be a str")
        pulumi.set(__self__, "cart_id", cart_id)
        if catalog_name and not isinstance(catalog_name, str):
            raise TypeError("Expected argument 'catalog_name' to be a str")
        pulumi.set(__self__, "catalog_name", catalog_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if plan_code and not isinstance(plan_code, str):
            raise TypeError("Expected argument 'plan_code' to be a str")
        pulumi.set(__self__, "plan_code", plan_code)
        if product and not isinstance(product, str):
            raise TypeError("Expected argument 'product' to be a str")
        pulumi.set(__self__, "product", product)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)

    @property
    @pulumi.getter(name="cartId")
    def cart_id(self) -> builtins.str:
        return pulumi.get(self, "cart_id")

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[builtins.str]:
        return pulumi.get(self, "catalog_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Product offer identifier
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter
    def product(self) -> builtins.str:
        return pulumi.get(self, "product")

    @property
    @pulumi.getter
    def results(self) -> Sequence['outputs.GetCartProductOptionsResultResult']:
        """
        products results
        """
        return pulumi.get(self, "results")


class AwaitableGetCartProductOptionsResult(GetCartProductOptionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCartProductOptionsResult(
            cart_id=self.cart_id,
            catalog_name=self.catalog_name,
            id=self.id,
            plan_code=self.plan_code,
            product=self.product,
            results=self.results)


def get_cart_product_options(cart_id: Optional[builtins.str] = None,
                             catalog_name: Optional[builtins.str] = None,
                             plan_code: Optional[builtins.str] = None,
                             product: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCartProductOptionsResult:
    """
    Use this data source to retrieve information of order cart product options.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_account = ovh.Me.get_me()
    my_cart = ovh.Order.get_cart(ovh_subsidiary=my_account.ovh_subsidiary)
    options = ovh.Order.get_cart_product_options(cart_id=my_cart.id,
        product="cloud",
        plan_code="project")
    ```


    :param builtins.str cart_id: Cart identifier
    :param builtins.str catalog_name: Catalog name
    :param builtins.str plan_code: Product offer identifier
    :param builtins.str product: Product
    """
    __args__ = dict()
    __args__['cartId'] = cart_id
    __args__['catalogName'] = catalog_name
    __args__['planCode'] = plan_code
    __args__['product'] = product
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Order/getCartProductOptions:getCartProductOptions', __args__, opts=opts, typ=GetCartProductOptionsResult).value

    return AwaitableGetCartProductOptionsResult(
        cart_id=pulumi.get(__ret__, 'cart_id'),
        catalog_name=pulumi.get(__ret__, 'catalog_name'),
        id=pulumi.get(__ret__, 'id'),
        plan_code=pulumi.get(__ret__, 'plan_code'),
        product=pulumi.get(__ret__, 'product'),
        results=pulumi.get(__ret__, 'results'))
def get_cart_product_options_output(cart_id: Optional[pulumi.Input[builtins.str]] = None,
                                    catalog_name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                    plan_code: Optional[pulumi.Input[builtins.str]] = None,
                                    product: Optional[pulumi.Input[builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCartProductOptionsResult]:
    """
    Use this data source to retrieve information of order cart product options.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_account = ovh.Me.get_me()
    my_cart = ovh.Order.get_cart(ovh_subsidiary=my_account.ovh_subsidiary)
    options = ovh.Order.get_cart_product_options(cart_id=my_cart.id,
        product="cloud",
        plan_code="project")
    ```


    :param builtins.str cart_id: Cart identifier
    :param builtins.str catalog_name: Catalog name
    :param builtins.str plan_code: Product offer identifier
    :param builtins.str product: Product
    """
    __args__ = dict()
    __args__['cartId'] = cart_id
    __args__['catalogName'] = catalog_name
    __args__['planCode'] = plan_code
    __args__['product'] = product
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Order/getCartProductOptions:getCartProductOptions', __args__, opts=opts, typ=GetCartProductOptionsResult)
    return __ret__.apply(lambda __response__: GetCartProductOptionsResult(
        cart_id=pulumi.get(__response__, 'cart_id'),
        catalog_name=pulumi.get(__response__, 'catalog_name'),
        id=pulumi.get(__response__, 'id'),
        plan_code=pulumi.get(__response__, 'plan_code'),
        product=pulumi.get(__response__, 'product'),
        results=pulumi.get(__response__, 'results')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, addresses=None, attached_volumes=None, availability_zone=None, flavor_id=None, flavor_name=None, id=None, image_id=None, instance_id=None, name=None, region=None, service_name=None, ssh_key=None, status=None, task_state=None):
        if addresses and not isinstance(addresses, list):
            raise TypeError("Expected argument 'addresses' to be a list")
        pulumi.set(__self__, "addresses", addresses)
        if attached_volumes and not isinstance(attached_volumes, list):
            raise TypeError("Expected argument 'attached_volumes' to be a list")
        pulumi.set(__self__, "attached_volumes", attached_volumes)
        if availability_zone and not isinstance(availability_zone, str):
            raise TypeError("Expected argument 'availability_zone' to be a str")
        pulumi.set(__self__, "availability_zone", availability_zone)
        if flavor_id and not isinstance(flavor_id, str):
            raise TypeError("Expected argument 'flavor_id' to be a str")
        pulumi.set(__self__, "flavor_id", flavor_id)
        if flavor_name and not isinstance(flavor_name, str):
            raise TypeError("Expected argument 'flavor_name' to be a str")
        pulumi.set(__self__, "flavor_name", flavor_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if ssh_key and not isinstance(ssh_key, str):
            raise TypeError("Expected argument 'ssh_key' to be a str")
        pulumi.set(__self__, "ssh_key", ssh_key)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if task_state and not isinstance(task_state, str):
            raise TypeError("Expected argument 'task_state' to be a str")
        pulumi.set(__self__, "task_state", task_state)

    @property
    @pulumi.getter
    def addresses(self) -> Sequence['outputs.GetInstanceAddressResult']:
        """
        Instance IP addresses
        """
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="attachedVolumes")
    def attached_volumes(self) -> Sequence['outputs.GetInstanceAttachedVolumeResult']:
        """
        Volumes attached to the instance
        """
        return pulumi.get(self, "attached_volumes")

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> builtins.str:
        """
        Availability zone of the instance
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="flavorId")
    def flavor_id(self) -> builtins.str:
        """
        Flavor id
        """
        return pulumi.get(self, "flavor_id")

    @property
    @pulumi.getter(name="flavorName")
    def flavor_name(self) -> builtins.str:
        """
        Flavor name
        """
        return pulumi.get(self, "flavor_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        Image id
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Instance name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sshKey")
    def ssh_key(self) -> builtins.str:
        """
        SSH Keypair
        """
        return pulumi.get(self, "ssh_key")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Instance status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="taskState")
    def task_state(self) -> builtins.str:
        """
        Instance task state
        """
        return pulumi.get(self, "task_state")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            addresses=self.addresses,
            attached_volumes=self.attached_volumes,
            availability_zone=self.availability_zone,
            flavor_id=self.flavor_id,
            flavor_name=self.flavor_name,
            id=self.id,
            image_id=self.image_id,
            instance_id=self.instance_id,
            name=self.name,
            region=self.region,
            service_name=self.service_name,
            ssh_key=self.ssh_key,
            status=self.status,
            task_state=self.task_state)


def get_instance(instance_id: Optional[builtins.str] = None,
                 region: Optional[builtins.str] = None,
                 service_name: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    **This datasource uses a Beta API** Use this data source to get the instance of a public cloud project.

    ## Example Usage

    To get information of an instance:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    instance = ovh.CloudProject.get_instance(service_name="YYYY",
        region="XXXX",
        instance_id="ZZZZZ")
    ```


    :param builtins.str instance_id: Instance id
    :param builtins.str region: Instance region
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        addresses=pulumi.get(__ret__, 'addresses'),
        attached_volumes=pulumi.get(__ret__, 'attached_volumes'),
        availability_zone=pulumi.get(__ret__, 'availability_zone'),
        flavor_id=pulumi.get(__ret__, 'flavor_id'),
        flavor_name=pulumi.get(__ret__, 'flavor_name'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        ssh_key=pulumi.get(__ret__, 'ssh_key'),
        status=pulumi.get(__ret__, 'status'),
        task_state=pulumi.get(__ret__, 'task_state'))
def get_instance_output(instance_id: Optional[pulumi.Input[builtins.str]] = None,
                        region: Optional[pulumi.Input[builtins.str]] = None,
                        service_name: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceResult]:
    """
    **This datasource uses a Beta API** Use this data source to get the instance of a public cloud project.

    ## Example Usage

    To get information of an instance:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    instance = ovh.CloudProject.get_instance(service_name="YYYY",
        region="XXXX",
        instance_id="ZZZZZ")
    ```


    :param builtins.str instance_id: Instance id
    :param builtins.str region: Instance region
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult)
    return __ret__.apply(lambda __response__: GetInstanceResult(
        addresses=pulumi.get(__response__, 'addresses'),
        attached_volumes=pulumi.get(__response__, 'attached_volumes'),
        availability_zone=pulumi.get(__response__, 'availability_zone'),
        flavor_id=pulumi.get(__response__, 'flavor_id'),
        flavor_name=pulumi.get(__response__, 'flavor_name'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        ssh_key=pulumi.get(__response__, 'ssh_key'),
        status=pulumi.get(__response__, 'status'),
        task_state=pulumi.get(__response__, 'task_state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IpRestrictionArgs', 'IpRestriction']

@pulumi.input_type
class IpRestrictionArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 engine: pulumi.Input[builtins.str],
                 ip: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a IpRestriction resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] ip: Authorized IP.
        :param pulumi.Input[builtins.str] description: Description of the IP restriction.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "engine", engine)
        pulumi.set(__self__, "ip", ip)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Input[builtins.str]:
        """
        The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[builtins.str]:
        """
        Authorized IP.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the IP restriction.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _IpRestrictionState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpRestriction resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] description: Description of the IP restriction.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] ip: Authorized IP.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the IP restriction.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if engine is not None:
            pulumi.set(__self__, "engine", engine)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the IP restriction.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def engine(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @engine.setter
    def engine(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "engine", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Authorized IP.
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current status of the IP restriction.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:CloudProjectDatabase/ipRestriction:IpRestriction")
class IpRestriction(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Deprecated: Use ip_restriction field in cloud_project_database resource instead. Continuing to use the CloudProjectDatabase.IpRestriction resource to add an IP restriction to a cloud_project_database resource will cause the cloud_project_database resource to be updated on every apply

        Apply IP restrictions to an OVHcloud Managed Database cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="YYYY",
            id="ZZZZ")
        ip_restriction = ovh.cloud_project_database.IpRestriction("ip_restriction",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            ip="178.97.6.0/24")
        ```

        ## Import

        OVHcloud Managed database cluster IP restrictions can be imported using the `service_name`, `engine`, `cluster_id` and the `ip`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/ipRestriction:IpRestriction my_ip_restriction service_name/engine/cluster_id/178.97.6.0/24
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] description: Description of the IP restriction.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] ip: Authorized IP.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpRestrictionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Deprecated: Use ip_restriction field in cloud_project_database resource instead. Continuing to use the CloudProjectDatabase.IpRestriction resource to add an IP restriction to a cloud_project_database resource will cause the cloud_project_database resource to be updated on every apply

        Apply IP restrictions to an OVHcloud Managed Database cluster.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        db = ovh.CloudProjectDatabase.get_database(service_name="XXXX",
            engine="YYYY",
            id="ZZZZ")
        ip_restriction = ovh.cloud_project_database.IpRestriction("ip_restriction",
            service_name=db.service_name,
            engine=db.engine,
            cluster_id=db.id,
            ip="178.97.6.0/24")
        ```

        ## Import

        OVHcloud Managed database cluster IP restrictions can be imported using the `service_name`, `engine`, `cluster_id` and the `ip`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/ipRestriction:IpRestriction my_ip_restriction service_name/engine/cluster_id/178.97.6.0/24
        ```

        :param str resource_name: The name of the resource.
        :param IpRestrictionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpRestrictionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 engine: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpRestrictionArgs.__new__(IpRestrictionArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["description"] = description
            if engine is None and not opts.urn:
                raise TypeError("Missing required property 'engine'")
            __props__.__dict__["engine"] = engine
            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["status"] = None
        super(IpRestriction, __self__).__init__(
            'ovh:CloudProjectDatabase/ipRestriction:IpRestriction',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            engine: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'IpRestriction':
        """
        Get an existing IpRestriction resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] description: Description of the IP restriction.
        :param pulumi.Input[builtins.str] engine: The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        :param pulumi.Input[builtins.str] ip: Authorized IP.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the IP restriction.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpRestrictionState.__new__(_IpRestrictionState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["description"] = description
        __props__.__dict__["engine"] = engine
        __props__.__dict__["ip"] = ip
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return IpRestriction(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description of the IP restriction.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def engine(self) -> pulumi.Output[builtins.str]:
        """
        The engine of the database cluster you want to add an IP restriction. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        Authorized IP.
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current status of the IP restriction.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['WorkflowBackupArgs', 'WorkflowBackup']

@pulumi.input_type
class WorkflowBackupArgs:
    def __init__(__self__, *,
                 cron: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 region_name: pulumi.Input[builtins.str],
                 rotation: pulumi.Input[builtins.int],
                 backup_name: Optional[pulumi.Input[builtins.str]] = None,
                 max_execution_count: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a WorkflowBackup resource.
        :param pulumi.Input[builtins.str] cron: The cron periodicity at which the backup workflow is scheduled
               
               * `instanceId` the id of the instance to back up
        :param pulumi.Input[builtins.str] region_name: The name of the openstack region.
        :param pulumi.Input[builtins.int] rotation: The number of backup that are retained.
        :param pulumi.Input[builtins.str] backup_name: The name of the backup files that are created. If empty, the `name` attribute is used.
        :param pulumi.Input[builtins.int] max_execution_count: The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        :param pulumi.Input[builtins.str] name: The worflow name that is used in the UI
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "cron", cron)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "region_name", region_name)
        pulumi.set(__self__, "rotation", rotation)
        if backup_name is not None:
            pulumi.set(__self__, "backup_name", backup_name)
        if max_execution_count is not None:
            pulumi.set(__self__, "max_execution_count", max_execution_count)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def cron(self) -> pulumi.Input[builtins.str]:
        """
        The cron periodicity at which the backup workflow is scheduled

        * `instanceId` the id of the instance to back up
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cron", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the openstack region.
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter
    def rotation(self) -> pulumi.Input[builtins.int]:
        """
        The number of backup that are retained.
        """
        return pulumi.get(self, "rotation")

    @rotation.setter
    def rotation(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "rotation", value)

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the backup files that are created. If empty, the `name` attribute is used.
        """
        return pulumi.get(self, "backup_name")

    @backup_name.setter
    def backup_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_name", value)

    @property
    @pulumi.getter(name="maxExecutionCount")
    def max_execution_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        """
        return pulumi.get(self, "max_execution_count")

    @max_execution_count.setter
    def max_execution_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_execution_count", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The worflow name that is used in the UI
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _WorkflowBackupState:
    def __init__(__self__, *,
                 backup_name: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 cron: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_execution_count: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering WorkflowBackup resources.
        :param pulumi.Input[builtins.str] backup_name: The name of the backup files that are created. If empty, the `name` attribute is used.
        :param pulumi.Input[builtins.str] cron: The cron periodicity at which the backup workflow is scheduled
               
               * `instanceId` the id of the instance to back up
        :param pulumi.Input[builtins.int] max_execution_count: The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        :param pulumi.Input[builtins.str] name: The worflow name that is used in the UI
        :param pulumi.Input[builtins.str] region_name: The name of the openstack region.
        :param pulumi.Input[builtins.int] rotation: The number of backup that are retained.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        if backup_name is not None:
            pulumi.set(__self__, "backup_name", backup_name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if cron is not None:
            pulumi.set(__self__, "cron", cron)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if max_execution_count is not None:
            pulumi.set(__self__, "max_execution_count", max_execution_count)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if rotation is not None:
            pulumi.set(__self__, "rotation", rotation)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the backup files that are created. If empty, the `name` attribute is used.
        """
        return pulumi.get(self, "backup_name")

    @backup_name.setter
    def backup_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "backup_name", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def cron(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The cron periodicity at which the backup workflow is scheduled

        * `instanceId` the id of the instance to back up
        """
        return pulumi.get(self, "cron")

    @cron.setter
    def cron(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cron", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="maxExecutionCount")
    def max_execution_count(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        """
        return pulumi.get(self, "max_execution_count")

    @max_execution_count.setter
    def max_execution_count(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_execution_count", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The worflow name that is used in the UI
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the openstack region.
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter
    def rotation(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The number of backup that are retained.
        """
        return pulumi.get(self, "rotation")

    @rotation.setter
    def rotation(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "rotation", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:CloudProject/workflowBackup:WorkflowBackup")
class WorkflowBackup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_name: Optional[pulumi.Input[builtins.str]] = None,
                 cron: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_execution_count: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manage a worflow that schedules backups of public cloud instance. Note that upon deletion, the workflow is deleted but any backups that have been created by this workflow are not.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_backup = ovh.cloud_project.WorkflowBackup("my_backup",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            region_name="GRA11",
            cron="50 4 * * *",
            instance_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxx",
            max_execution_count=0,
            name="Backup workflow for instance",
            rotation=7)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] backup_name: The name of the backup files that are created. If empty, the `name` attribute is used.
        :param pulumi.Input[builtins.str] cron: The cron periodicity at which the backup workflow is scheduled
               
               * `instanceId` the id of the instance to back up
        :param pulumi.Input[builtins.int] max_execution_count: The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        :param pulumi.Input[builtins.str] name: The worflow name that is used in the UI
        :param pulumi.Input[builtins.str] region_name: The name of the openstack region.
        :param pulumi.Input[builtins.int] rotation: The number of backup that are retained.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkflowBackupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage a worflow that schedules backups of public cloud instance. Note that upon deletion, the workflow is deleted but any backups that have been created by this workflow are not.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_backup = ovh.cloud_project.WorkflowBackup("my_backup",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            region_name="GRA11",
            cron="50 4 * * *",
            instance_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxx",
            max_execution_count=0,
            name="Backup workflow for instance",
            rotation=7)
        ```

        :param str resource_name: The name of the resource.
        :param WorkflowBackupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkflowBackupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_name: Optional[pulumi.Input[builtins.str]] = None,
                 cron: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_execution_count: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 rotation: Optional[pulumi.Input[builtins.int]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkflowBackupArgs.__new__(WorkflowBackupArgs)

            __props__.__dict__["backup_name"] = backup_name
            if cron is None and not opts.urn:
                raise TypeError("Missing required property 'cron'")
            __props__.__dict__["cron"] = cron
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["max_execution_count"] = max_execution_count
            __props__.__dict__["name"] = name
            if region_name is None and not opts.urn:
                raise TypeError("Missing required property 'region_name'")
            __props__.__dict__["region_name"] = region_name
            if rotation is None and not opts.urn:
                raise TypeError("Missing required property 'rotation'")
            __props__.__dict__["rotation"] = rotation
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["created_at"] = None
        super(WorkflowBackup, __self__).__init__(
            'ovh:CloudProject/workflowBackup:WorkflowBackup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_name: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            cron: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            max_execution_count: Optional[pulumi.Input[builtins.int]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            region_name: Optional[pulumi.Input[builtins.str]] = None,
            rotation: Optional[pulumi.Input[builtins.int]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None) -> 'WorkflowBackup':
        """
        Get an existing WorkflowBackup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] backup_name: The name of the backup files that are created. If empty, the `name` attribute is used.
        :param pulumi.Input[builtins.str] cron: The cron periodicity at which the backup workflow is scheduled
               
               * `instanceId` the id of the instance to back up
        :param pulumi.Input[builtins.int] max_execution_count: The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        :param pulumi.Input[builtins.str] name: The worflow name that is used in the UI
        :param pulumi.Input[builtins.str] region_name: The name of the openstack region.
        :param pulumi.Input[builtins.int] rotation: The number of backup that are retained.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkflowBackupState.__new__(_WorkflowBackupState)

        __props__.__dict__["backup_name"] = backup_name
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["cron"] = cron
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["max_execution_count"] = max_execution_count
        __props__.__dict__["name"] = name
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["rotation"] = rotation
        __props__.__dict__["service_name"] = service_name
        return WorkflowBackup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupName")
    def backup_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the backup files that are created. If empty, the `name` attribute is used.
        """
        return pulumi.get(self, "backup_name")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def cron(self) -> pulumi.Output[builtins.str]:
        """
        The cron periodicity at which the backup workflow is scheduled

        * `instanceId` the id of the instance to back up
        """
        return pulumi.get(self, "cron")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="maxExecutionCount")
    def max_execution_count(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The number of times the worflow is run. Default value is `0` which means that the workflow will be scheduled continously until its deletion
        """
        return pulumi.get(self, "max_execution_count")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The worflow name that is used in the UI
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the openstack region.
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter
    def rotation(self) -> pulumi.Output[builtins.int]:
        """
        The number of backup that are retained.
        """
        return pulumi.get(self, "rotation")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerNetworkingArgs', 'ServerNetworking']

@pulumi.input_type
class ServerNetworkingArgs:
    def __init__(__self__, *,
                 interfaces: pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a ServerNetworking resource.
        :param pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]] interfaces: Interface or interfaces aggregation.
        :param pulumi.Input[builtins.str] service_name: The internal name of your dedicated server.
        """
        pulumi.set(__self__, "interfaces", interfaces)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def interfaces(self) -> pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]]:
        """
        Interface or interfaces aggregation.
        """
        return pulumi.get(self, "interfaces")

    @interfaces.setter
    def interfaces(self, value: pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]]):
        pulumi.set(self, "interfaces", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _ServerNetworkingState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerNetworking resources.
        :param pulumi.Input[builtins.str] description: Operation description
        :param pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]] interfaces: Interface or interfaces aggregation.
        :param pulumi.Input[builtins.str] service_name: The internal name of your dedicated server.
        :param pulumi.Input[builtins.str] status: Operation status
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if interfaces is not None:
            pulumi.set(__self__, "interfaces", interfaces)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Operation description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]]]:
        """
        Interface or interfaces aggregation.
        """
        return pulumi.get(self, "interfaces")

    @interfaces.setter
    def interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerNetworkingInterfaceArgs']]]]):
        pulumi.set(self, "interfaces", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Operation status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:Dedicated/serverNetworking:ServerNetworking")
class ServerNetworking(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerNetworkingInterfaceArgs', 'ServerNetworkingInterfaceArgsDict']]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Create a ServerNetworking resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerNetworkingInterfaceArgs', 'ServerNetworkingInterfaceArgsDict']]]] interfaces: Interface or interfaces aggregation.
        :param pulumi.Input[builtins.str] service_name: The internal name of your dedicated server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerNetworkingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a ServerNetworking resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ServerNetworkingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerNetworkingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerNetworkingInterfaceArgs', 'ServerNetworkingInterfaceArgsDict']]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerNetworkingArgs.__new__(ServerNetworkingArgs)

            if interfaces is None and not opts.urn:
                raise TypeError("Missing required property 'interfaces'")
            __props__.__dict__["interfaces"] = interfaces
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["description"] = None
            __props__.__dict__["status"] = None
        super(ServerNetworking, __self__).__init__(
            'ovh:Dedicated/serverNetworking:ServerNetworking',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerNetworkingInterfaceArgs', 'ServerNetworkingInterfaceArgsDict']]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ServerNetworking':
        """
        Get an existing ServerNetworking resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Operation description
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerNetworkingInterfaceArgs', 'ServerNetworkingInterfaceArgsDict']]]] interfaces: Interface or interfaces aggregation.
        :param pulumi.Input[builtins.str] service_name: The internal name of your dedicated server.
        :param pulumi.Input[builtins.str] status: Operation status
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerNetworkingState.__new__(_ServerNetworkingState)

        __props__.__dict__["description"] = description
        __props__.__dict__["interfaces"] = interfaces
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return ServerNetworking(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Operation description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def interfaces(self) -> pulumi.Output[Sequence['outputs.ServerNetworkingInterface']]:
        """
        Interface or interfaces aggregation.
        """
        return pulumi.get(self, "interfaces")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Operation status
        """
        return pulumi.get(self, "status")

